{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "B h-\N{U+056b}\N{U+0576}",
    Bhm => "B h:mm-\N{U+056b}\N{U+0576}",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm-\N{U+056b}\N{U+0576}",
    EBhms => "E B h:mm:ss",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "d, ccc",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "G y \N{U+0569}.",
    GyMMM => "G y \N{U+0569}. MMM",
    GyMMMEd => "G y \N{U+0569}. MMM d, E",
    GyMMMd => "G y \N{U+0569}\N{U+2024} MMM d",
    GyMd => "dd.MM.y GGGGG",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "dd.MM, E",
    MMM => "LLL",
    MMMEd => "d MMM, E",
    "MMMMW-count-one" => "MMMM W-\N{U+056b}\N{U+0576} \N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
    "MMMMW-count-other" => "MMMM W-\N{U+0580}\N{U+0564} \N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd.MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "d.MM.y \N{U+0569}., E",
    yMMM => "y \N{U+0569}. LLL",
    yMMMEd => "y \N{U+0569}. MMM d, E",
    yMMMM => "y \N{U+0569}\N{U+2024} LLLL",
    yMMMd => "d MMM, y \N{U+0569}.",
    yMd => "dd.MM.y",
    yQQQ => "y \N{U+0569}. QQQ",
    yQQQQ => "y \N{U+0569}. QQQQ",
    "yw-count-one" => "Y \N{U+0569}\N{U+2024} w-\N{U+056b}\N{U+0576} \N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
    "yw-count-other" => "Y \N{U+0569}\N{U+2024} w-\N{U+0580}\N{U+0564} \N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
  },
  code => "hy-AM",
  date_format_full => "y \N{U+0569}. MMMM d, EEEE",
  date_format_long => "dd MMMM, y \N{U+0569}.",
  date_format_medium => "dd MMM, y \N{U+0569}.",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0565}\N{U+0580}\N{U+056f}",
    "\N{U+0565}\N{U+0580}\N{U+0584}",
    "\N{U+0579}\N{U+0580}\N{U+0584}",
    "\N{U+0570}\N{U+0576}\N{U+0563}",
    "\N{U+0578}\N{U+0582}\N{U+0580}",
    "\N{U+0577}\N{U+0562}\N{U+0569}",
    "\N{U+056f}\N{U+056b}\N{U+0580}",
  ],
  day_format_narrow => [
    "\N{U+0535}",
    "\N{U+0535}",
    "\N{U+0549}",
    "\N{U+0540}",
    "\N{U+0548}",
    "\N{U+0547}",
    "\N{U+053f}",
  ],
  day_format_wide => [
    "\N{U+0565}\N{U+0580}\N{U+056f}\N{U+0578}\N{U+0582}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0565}\N{U+0580}\N{U+0565}\N{U+0584}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0579}\N{U+0578}\N{U+0580}\N{U+0565}\N{U+0584}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0570}\N{U+056b}\N{U+0576}\N{U+0563}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0578}\N{U+0582}\N{U+0580}\N{U+0562}\N{U+0561}\N{U+0569}",
    "\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
    "\N{U+056f}\N{U+056b}\N{U+0580}\N{U+0561}\N{U+056f}\N{U+056b}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0565}\N{U+0580}\N{U+056f}",
    "\N{U+0565}\N{U+0580}\N{U+0584}",
    "\N{U+0579}\N{U+0580}\N{U+0584}",
    "\N{U+0570}\N{U+0576}\N{U+0563}",
    "\N{U+0578}\N{U+0582}\N{U+0580}",
    "\N{U+0577}\N{U+0562}\N{U+0569}",
    "\N{U+056f}\N{U+056b}\N{U+0580}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0535}",
    "\N{U+0535}",
    "\N{U+0549}",
    "\N{U+0540}",
    "\N{U+0548}",
    "\N{U+0547}",
    "\N{U+053f}",
  ],
  day_stand_alone_wide => [
    "\N{U+0565}\N{U+0580}\N{U+056f}\N{U+0578}\N{U+0582}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0565}\N{U+0580}\N{U+0565}\N{U+0584}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0579}\N{U+0578}\N{U+0580}\N{U+0565}\N{U+0584}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0570}\N{U+056b}\N{U+0576}\N{U+0563}\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0569}\N{U+056b}",
    "\N{U+0578}\N{U+0582}\N{U+0580}\N{U+0562}\N{U+0561}\N{U+0569}",
    "\N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
    "\N{U+056f}\N{U+056b}\N{U+0580}\N{U+0561}\N{U+056f}\N{U+056b}",
  ],
  era_abbreviated => [
    "\N{U+0574}.\N{U+0569}.\N{U+0561}.",
    "\N{U+0574}.\N{U+0569}.",
  ],
  era_narrow => [
    "\N{U+0574}.\N{U+0569}.\N{U+0561}.",
    "\N{U+0574}.\N{U+0569}.",
  ],
  era_wide => [
    "\N{U+0554}\N{U+0580}\N{U+056b}\N{U+057d}\N{U+057f}\N{U+0578}\N{U+057d}\N{U+056b}\N{U+0581} \N{U+0561}\N{U+057c}\N{U+0561}\N{U+057b}",
    "\N{U+0554}\N{U+0580}\N{U+056b}\N{U+057d}\N{U+057f}\N{U+0578}\N{U+057d}\N{U+056b}\N{U+0581} \N{U+0570}\N{U+0565}\N{U+057f}\N{U+0578}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %r %Z",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %d %b %Y %r",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Armenian",
  month_format_abbreviated => [
    "\N{U+0570}\N{U+0576}\N{U+057e}",
    "\N{U+0583}\N{U+057f}\N{U+057e}",
    "\N{U+0574}\N{U+0580}\N{U+057f}",
    "\N{U+0561}\N{U+057a}\N{U+0580}",
    "\N{U+0574}\N{U+0575}\N{U+057d}",
    "\N{U+0570}\N{U+0576}\N{U+057d}",
    "\N{U+0570}\N{U+056c}\N{U+057d}",
    "\N{U+0585}\N{U+0563}\N{U+057d}",
    "\N{U+057d}\N{U+0565}\N{U+057a}",
    "\N{U+0570}\N{U+0578}\N{U+056f}",
    "\N{U+0576}\N{U+0578}\N{U+0575}",
    "\N{U+0564}\N{U+0565}\N{U+056f}",
  ],
  month_format_narrow => [
    "\N{U+0540}",
    "\N{U+0553}",
    "\N{U+0544}",
    "\N{U+0531}",
    "\N{U+0544}",
    "\N{U+0540}",
    "\N{U+0540}",
    "\N{U+0555}",
    "\N{U+054d}",
    "\N{U+0540}",
    "\N{U+0546}",
    "\N{U+0534}",
  ],
  month_format_wide => [
    "\N{U+0570}\N{U+0578}\N{U+0582}\N{U+0576}\N{U+057e}\N{U+0561}\N{U+0580}\N{U+056b}",
    "\N{U+0583}\N{U+0565}\N{U+057f}\N{U+0580}\N{U+057e}\N{U+0561}\N{U+0580}\N{U+056b}",
    "\N{U+0574}\N{U+0561}\N{U+0580}\N{U+057f}\N{U+056b}",
    "\N{U+0561}\N{U+057a}\N{U+0580}\N{U+056b}\N{U+056c}\N{U+056b}",
    "\N{U+0574}\N{U+0561}\N{U+0575}\N{U+056b}\N{U+057d}\N{U+056b}",
    "\N{U+0570}\N{U+0578}\N{U+0582}\N{U+0576}\N{U+056b}\N{U+057d}\N{U+056b}",
    "\N{U+0570}\N{U+0578}\N{U+0582}\N{U+056c}\N{U+056b}\N{U+057d}\N{U+056b}",
    "\N{U+0585}\N{U+0563}\N{U+0578}\N{U+057d}\N{U+057f}\N{U+0578}\N{U+057d}\N{U+056b}",
    "\N{U+057d}\N{U+0565}\N{U+057a}\N{U+057f}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}\N{U+056b}",
    "\N{U+0570}\N{U+0578}\N{U+056f}\N{U+057f}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}\N{U+056b}",
    "\N{U+0576}\N{U+0578}\N{U+0575}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}\N{U+056b}",
    "\N{U+0564}\N{U+0565}\N{U+056f}\N{U+057f}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}\N{U+056b}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0570}\N{U+0576}\N{U+057e}",
    "\N{U+0583}\N{U+057f}\N{U+057e}",
    "\N{U+0574}\N{U+0580}\N{U+057f}",
    "\N{U+0561}\N{U+057a}\N{U+0580}",
    "\N{U+0574}\N{U+0575}\N{U+057d}",
    "\N{U+0570}\N{U+0576}\N{U+057d}",
    "\N{U+0570}\N{U+056c}\N{U+057d}",
    "\N{U+0585}\N{U+0563}\N{U+057d}",
    "\N{U+057d}\N{U+0565}\N{U+057a}",
    "\N{U+0570}\N{U+0578}\N{U+056f}",
    "\N{U+0576}\N{U+0578}\N{U+0575}",
    "\N{U+0564}\N{U+0565}\N{U+056f}",
  ],
  month_stand_alone_narrow => [
    "\N{U+0540}",
    "\N{U+0553}",
    "\N{U+0544}",
    "\N{U+0531}",
    "\N{U+0544}",
    "\N{U+0540}",
    "\N{U+0540}",
    "\N{U+0555}",
    "\N{U+054d}",
    "\N{U+0540}",
    "\N{U+0546}",
    "\N{U+0534}",
  ],
  month_stand_alone_wide => [
    "\N{U+0570}\N{U+0578}\N{U+0582}\N{U+0576}\N{U+057e}\N{U+0561}\N{U+0580}",
    "\N{U+0583}\N{U+0565}\N{U+057f}\N{U+0580}\N{U+057e}\N{U+0561}\N{U+0580}",
    "\N{U+0574}\N{U+0561}\N{U+0580}\N{U+057f}",
    "\N{U+0561}\N{U+057a}\N{U+0580}\N{U+056b}\N{U+056c}",
    "\N{U+0574}\N{U+0561}\N{U+0575}\N{U+056b}\N{U+057d}",
    "\N{U+0570}\N{U+0578}\N{U+0582}\N{U+0576}\N{U+056b}\N{U+057d}",
    "\N{U+0570}\N{U+0578}\N{U+0582}\N{U+056c}\N{U+056b}\N{U+057d}",
    "\N{U+0585}\N{U+0563}\N{U+0578}\N{U+057d}\N{U+057f}\N{U+0578}\N{U+057d}",
    "\N{U+057d}\N{U+0565}\N{U+057a}\N{U+057f}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}",
    "\N{U+0570}\N{U+0578}\N{U+056f}\N{U+057f}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}",
    "\N{U+0576}\N{U+0578}\N{U+0575}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}",
    "\N{U+0564}\N{U+0565}\N{U+056f}\N{U+057f}\N{U+0565}\N{U+0574}\N{U+0562}\N{U+0565}\N{U+0580}",
  ],
  name => "Armenian Armenia",
  native_language => "\N{U+0570}\N{U+0561}\N{U+0575}\N{U+0565}\N{U+0580}\N{U+0565}\N{U+0576}",
  native_name => "\N{U+0570}\N{U+0561}\N{U+0575}\N{U+0565}\N{U+0580}\N{U+0565}\N{U+0576} \N{U+0540}\N{U+0561}\N{U+0575}\N{U+0561}\N{U+057d}\N{U+057f}\N{U+0561}\N{U+0576}",
  native_script => undef,
  native_territory => "\N{U+0540}\N{U+0561}\N{U+0575}\N{U+0561}\N{U+057d}\N{U+057f}\N{U+0561}\N{U+0576}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-\N{U+056b}\N{U+0576} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
    "2-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
    "3-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
    "4-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-\N{U+056b}\N{U+0576} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
    "2-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
    "3-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
    "4-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
  ],
  quarter_stand_alone_abbreviated => [
    "1-\N{U+056b}\N{U+0576} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
    "2-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
    "3-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
    "4-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0574}\N{U+057d}.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-\N{U+056b}\N{U+0576} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
    "2-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
    "3-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
    "4-\N{U+0580}\N{U+0564} \N{U+0565}\N{U+057c}\N{U+0561}\N{U+0574}\N{U+057d}\N{U+0575}\N{U+0561}\N{U+056f}",
  ],
  script => undef,
  territory => "Armenia",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
